pub struct BasicAllowance {
pub spend_limit: Vec<Coin>,
pub expiration: Option<Timestamp>,
}Expand description
BasicAllowance implements Allowance with a one-time grant of coins that optionally expires. The grantee can use up to SpendLimit to cover fees.
Fields
spend_limit: Vec<Coin>spend_limit specifies the maximum amount of coins that can be spent by this allowance and will be updated as coins are spent. If it is empty, there is no spend limit and any amount of coins can be spent.
expiration: Option<Timestamp>expiration specifies an optional time when this allowance expires
Implementations