Height

Struct Height 

pub struct Height {
    pub revision_number: u64,
    pub revision_height: u64,
}
Height is a monotonically increasing data type that can be compared against another Height for the purposes of updating and freezing clients

Normally the RevisionHeight is incremented at each height while keeping RevisionNumber the same. However some consensus algorithms may choose to reset the height in certain conditions e.g. hard forks, state-machine breaking changes In these cases, the RevisionNumber is incremented so that height continues to be monitonically increasing even as the RevisionHeight gets reset

Fields

revision_number: u64

the revision that the client is currently on

revision_height: u64

the height within the given revision

Implementations

Source

impl Height

pub const TYPE_URL: &'static str = "/ibc.core.client.v1.Height"