Contains the querier that can be used to query data related to the x/posts module.
Structs
- Posts
Querier - Querier allows to query data from the Desmos x/posts module.
Contains the querier that can be used to query data related to the x/posts module.