#[repr(i32)]pub enum PostReferenceType {
Unspecified = 0,
Reply = 1,
Quote = 2,
Repost = 3,
}Expand description
PostReferenceType represents the different types of references
Variants
Unspecified = 0
No reference specified
Reply = 1
This reference represents a reply to the specified post
Quote = 2
This reference represents a quote of the specified post
Repost = 3
This reference represents a repost of the specified post
Implementations
Sourceimpl PostReferenceType
impl PostReferenceType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.
pub fn serialize<S>(v: &i32, serializer: S) -> Result<S::Ok, S::Error>where
S: Serializer,
pub fn deserialize<'de, D>(deserializer: D) -> Result<i32, D::Error>where
D: Deserializer<'de>,