#[repr(i32)]pub enum ReplySetting {
Unspecified = 0,
Everyone = 1,
Followers = 2,
Mutual = 3,
Mentions = 4,
}Expand description
ReplySetting contains the possible reply settings that a post can have
Variants
Unspecified = 0
No reply setting specified
Everyone = 1
Everyone will be able to reply to this post
Followers = 2
Only followers of the author will be able to reply to this post
Mutual = 3
Only the author mutual followers will be able to reply to this post
Mentions = 4
Only people mentioned inside this post will be able to reply
Implementations
Sourceimpl ReplySetting
impl ReplySetting
Sourceimpl ReplySetting
impl ReplySetting
Sourceimpl ReplySetting
impl ReplySetting
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.
pub fn serialize<S>(v: &i32, serializer: S) -> Result<S::Ok, S::Error>where
S: Serializer,
pub fn deserialize<'de, D>(deserializer: D) -> Result<i32, D::Error>where
D: Deserializer<'de>,