pub struct Attachment {
pub subspace_id: u64,
pub post_id: u64,
pub id: u32,
pub content: Option<Any>,
}Expand description
Attachment contains the data of a single post attachment
Fields
subspace_id: u64Id of the subspace inside which the post to which this attachment should be connected is
post_id: u64Id of the post to which this attachment should be connected
id: u32If of this attachment
content: Option<Any>Content of the attachment
Implementations