pub struct MsgAnswerPoll {
pub subspace_id: u64,
pub post_id: u64,
pub poll_id: u32,
pub answers_indexes: Vec<u32>,
pub signer: String,
}Expand description
MsgAnswerPoll represents the message used to answer a poll
Fields
subspace_id: u64Id of the subspace containing the post
post_id: u64Id of the post that contains the poll to be answered
poll_id: u32Id of the poll to be answered
answers_indexes: Vec<u32>Indexes of the answer inside the ProvidedAnswers array
signer: StringAddress of the user answering the poll
Implementations