pub struct MsgCancelPostOwnerTransferRequest {
pub subspace_id: u64,
pub post_id: u64,
pub sender: String,
}Expand description
MsgCancelPostOwnerTransferRequest represents a message used to cancel a outgoing post transfer request
Since: Desmos 6.0.0
Fields
subspace_id: u64Id of the subspace that holds the post for which the request should be canceled
post_id: u64Id of the post for which the request will be cancelled
sender: StringAddress of the transfer request sender
Implementations