pub struct MsgCreatePost {
pub subspace_id: u64,
pub section_id: u32,
pub external_id: String,
pub text: String,
pub entities: Option<Entities>,
pub tags: Vec<String>,
pub attachments: Vec<Any>,
pub author: String,
pub conversation_id: u64,
pub reply_settings: i32,
pub referenced_posts: Vec<PostReference>,
}Expand description
MsgCreatePost represents the message to be used to create a post.
Fields
subspace_id: u64Id of the subspace inside which the post must be created
section_id: u32Id of the section inside which the post must be created
external_id: String(optional) External id for this post
text: String(optional) Text of the post
entities: Option<Entities>(optional) Entities connected to this post
Tags connected to this post
attachments: Vec<Any>Attachments of the post
Author of the post
conversation_id: u64(optional) Id of the original post of the conversation
reply_settings: i32Reply settings of this post
referenced_posts: Vec<PostReference>A list this posts references (either as a reply, repost or quote)
Implementations
Sourceimpl MsgCreatePost
impl MsgCreatePost
Sourcepub fn reply_settings(&self) -> ReplySetting
pub fn reply_settings(&self) -> ReplySetting
Returns the enum value of reply_settings, or the default if the field is set to an invalid enum value.
Sourcepub fn set_reply_settings(&mut self, value: ReplySetting)
pub fn set_reply_settings(&mut self, value: ReplySetting)
Sets reply_settings to the provided enum value.