pub struct MsgEditPost {
pub subspace_id: u64,
pub post_id: u64,
pub text: String,
pub entities: Option<Entities>,
pub tags: Vec<String>,
pub editor: String,
}Expand description
MsgEditPost represents the message to be used to edit a post.
Fields
subspace_id: u64Id of the subspace inside which the post is
post_id: u64Id of the post to edit
text: StringNew text of the post. If set to [do-not-modify] it will change the current post’s text.
entities: Option<Entities>New entities connected to this post. These will always replace the current post’s entities
New tags connected to this post. These will always replace the current post’s tags
editor: StringEditor of the post
Implementations