pub struct MsgMovePost {
pub subspace_id: u64,
pub post_id: u64,
pub target_subspace_id: u64,
pub target_section_id: u32,
pub owner: String,
}Expand description
MsgMovePost moves a post to another subspace
Since: Desmos 6.0.0
Fields
subspace_id: u64Id of the subspace where the post is currently located
post_id: u64Id of the post to be moved
target_subspace_id: u64Id of the target subspace to which the post will be moved
target_section_id: u32Id of the target section to which the post will be moved
owner: StringAddress of the post owner
Implementations