pub struct MsgRefusePostOwnerTransferRequest {
pub subspace_id: u64,
pub post_id: u64,
pub receiver: String,
}Expand description
MsgRefusePostOwnerTransferRequest represents a message used to refuse a incoming post transfer request
Since: Desmos 6.0.0
Fields
subspace_id: u64Id of the subspace holding the post for which the request will be refused
post_id: u64Id of the post for which the request will be refused
receiver: StringAddress of the request receiver
Implementations