pub struct MsgRemovePostAttachment {
pub subspace_id: u64,
pub post_id: u64,
pub attachment_id: u32,
pub editor: String,
}Expand description
MsgRemovePostAttachment represents the message to be used when removing an attachment from a post
Fields
subspace_id: u64Id of the subspace containing the post
post_id: u64Id of the post from which to remove the attachment
attachment_id: u32Id of the attachment to be removed
editor: StringUser that is removing the attachment
Implementations