pub struct MsgRequestPostOwnerTransfer {
pub subspace_id: u64,
pub post_id: u64,
pub receiver: String,
pub sender: String,
}Expand description
MsgRequestPostOwnerTransfer represent a message used to transfer a post ownership to receiver
Since: Desmos 6.0.0
Fields
subspace_id: u64Id of the subspace that holds the post which ownership should be transfered
post_id: u64Id of the post which will be transferred
receiver: StringAddress of the post ownership receiver
sender: StringAddress of the sender who is creating a transfer request
Implementations