pub struct Poll {
pub question: String,
pub provided_answers: Vec<ProvidedAnswer>,
pub end_date: Option<Timestamp>,
pub allows_multiple_answers: bool,
pub allows_answer_edits: bool,
pub final_tally_results: Option<PollTallyResults>,
}Expand description
Poll represents a poll attachment
Fields
question: StringQuestion of the poll
provided_answers: Vec<ProvidedAnswer>Answers the users can choose from
end_date: Option<Timestamp>Date at which the poll will close
allows_multiple_answers: boolWhether the poll allows multiple choices from the same user or not
allows_answer_edits: boolWhether the poll allows to edit an answer or not
final_tally_results: Option<PollTallyResults>Final poll results
Implementations