pub struct Post {Show 14 fields
pub subspace_id: u64,
pub section_id: u32,
pub id: u64,
pub external_id: String,
pub text: String,
pub entities: Option<Entities>,
pub tags: Vec<String>,
pub author: String,
pub conversation_id: u64,
pub referenced_posts: Vec<PostReference>,
pub reply_settings: i32,
pub creation_date: Option<Timestamp>,
pub last_edited_date: Option<Timestamp>,
pub owner: String,
}Expand description
Post contains all the information about a single post
Fields
subspace_id: u64Id of the subspace inside which the post has been created
section_id: u32Id of the section inside which the post has been created
id: u64Unique id of the post
external_id: String(optional) External id for this post
text: String(optional) Text of the post
entities: Option<Entities>(optional) Entities connected to this post
Tags related to this post, useful for categorization
Author of the post
conversation_id: u64(optional) Id of the original post of the conversation
referenced_posts: Vec<PostReference>A list this posts references (either as a reply, repost or quote)
reply_settings: i32Reply settings of this post
creation_date: Option<Timestamp>Creation date of the post
last_edited_date: Option<Timestamp>(optional) Last edited time of the post
owner: StringOwner of the post
Implementations
Sourceimpl Post
impl Post
Sourcepub fn reply_settings(&self) -> ReplySetting
pub fn reply_settings(&self) -> ReplySetting
Returns the enum value of reply_settings, or the default if the field is set to an invalid enum value.
Sourcepub fn set_reply_settings(&mut self, value: ReplySetting)
pub fn set_reply_settings(&mut self, value: ReplySetting)
Sets reply_settings to the provided enum value.