pub struct PostOwnerTransferRequest {
pub subspace_id: u64,
pub post_id: u64,
pub sender: String,
pub receiver: String,
}Expand description
PostOwnerTransferRequest represents a request to transfer the ownership of a post from the sender to the receiver
Fields
subspace_id: u64Id of the subspace that holds the post to transfer
post_id: u64Id of the post which will be transferred
sender: StringAddress of the sender
receiver: StringAddress of the receiver
Implementations