pub struct PostReference {
pub type: i32,
pub post_id: u64,
pub position: u64,
}Expand description
PostReference contains the details of a post reference
Fields
type: i32Type of reference
post_id: u64Id of the referenced post
position: u64Position of the reference inside the post’s text. This should be used only with the type set to TYPE_QUOTE
Implementations
Sourceimpl PostReference
impl PostReference
Sourcepub fn type(&self) -> PostReferenceType
pub fn type(&self) -> PostReferenceType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: PostReferenceType)
pub fn set_type(&mut self, value: PostReferenceType)
Sets type to the provided enum value.