pub struct QueryIncomingPostOwnerTransferRequestsRequest {
pub subspace_id: u64,
pub receiver: String,
pub pagination: Option<PageRequest>,
}Expand description
QueryIncomingPostOwnerTransferRequestsRequest is the request type for the Query/IncomingPostOwnerTransferRequests RPC endpoint
Fields
subspace_id: u64Id of the subspace where the requests are stored
receiver: String(optional) Receiver represents the address of the user to which query the incoming requests for
pagination: Option<PageRequest>Pagination defines an optional pagination for the request
Implementations
Sourceimpl QueryIncomingPostOwnerTransferRequestsRequest
impl QueryIncomingPostOwnerTransferRequestsRequest
pub const TYPE_URL: &'static str = "/desmos.posts.v3.QueryIncomingPostOwnerTransferRequestsRequest"
pub fn query( self, querier: &QuerierWrapper<'_, impl CustomQuery>, ) -> StdResult<QueryIncomingPostOwnerTransferRequestsResponse>
pub fn mock_response<T: MockableQuerier>( querier: &mut T, response: QueryIncomingPostOwnerTransferRequestsResponse, )
pub fn mock_failed_response<T: MockableQuerier>(querier: &mut T, error: String)