pub struct QueryPollAnswersRequest {
pub subspace_id: u64,
pub post_id: u64,
pub poll_id: u32,
pub user: String,
pub pagination: Option<PageRequest>,
}Expand description
QueryPollAnswersRequest is the request type for the Query/PollAnswers RPC method
Fields
subspace_id: u64Id of the subspace where the post is stored
post_id: u64Id of the post that holds the poll
poll_id: u32Id of the poll to query the answers for
user: String(Optional) Address of the user to query the responses for
pagination: Option<PageRequest>pagination defines an optional pagination for the request.
Implementations
Sourceimpl QueryPollAnswersRequest
impl QueryPollAnswersRequest
pub const TYPE_URL: &'static str = "/desmos.posts.v3.QueryPollAnswersRequest"
pub fn query( self, querier: &QuerierWrapper<'_, impl CustomQuery>, ) -> StdResult<QueryPollAnswersResponse>
pub fn mock_response<T: MockableQuerier>( querier: &mut T, response: QueryPollAnswersResponse, )
pub fn mock_failed_response<T: MockableQuerier>(querier: &mut T, error: String)