pub struct QueryPostAttachmentsRequest {
pub subspace_id: u64,
pub post_id: u64,
pub pagination: Option<PageRequest>,
}Expand description
QueryPostsRequest is the request type for the Query/PostAttachments RPC method
Fields
subspace_id: u64Id of the subspace where the post is stored
post_id: u64Id of the post to query the attachments for
pagination: Option<PageRequest>pagination defines an optional pagination for the request.
Implementations
Sourceimpl QueryPostAttachmentsRequest
impl QueryPostAttachmentsRequest
pub const TYPE_URL: &'static str = "/desmos.posts.v3.QueryPostAttachmentsRequest"
pub fn query( self, querier: &QuerierWrapper<'_, impl CustomQuery>, ) -> StdResult<QueryPostAttachmentsResponse>
pub fn mock_response<T: MockableQuerier>( querier: &mut T, response: QueryPostAttachmentsResponse, )
pub fn mock_failed_response<T: MockableQuerier>(querier: &mut T, error: String)