pub struct QuerySectionPostsRequest {
pub subspace_id: u64,
pub section_id: u32,
pub pagination: Option<PageRequest>,
}Expand description
QuerySectionPostsRequest is the request type for the Query/SectionPosts RPC method
Fields
subspace_id: u64Id of the subspace to query the posts for
section_id: u32Id of the section to query the posts for
pagination: Option<PageRequest>pagination defines an optional pagination for the request.
Implementations
Sourceimpl QuerySectionPostsRequest
impl QuerySectionPostsRequest
pub const TYPE_URL: &'static str = "/desmos.posts.v3.QuerySectionPostsRequest"
pub fn query( self, querier: &QuerierWrapper<'_, impl CustomQuery>, ) -> StdResult<QuerySectionPostsResponse>
pub fn mock_response<T: MockableQuerier>( querier: &mut T, response: QuerySectionPostsResponse, )
pub fn mock_failed_response<T: MockableQuerier>(querier: &mut T, error: String)