#[repr(i32)]pub enum ApplicationLinkState {
InitializedUnspecified = 0,
VerificationStarted = 1,
VerificationError = 2,
VerificationSuccess = 3,
TimedOut = 4,
}Expand description
ApplicationLinkState defines if an application link is in the following states: STARTED, ERRORED, SUCCESSFUL, TIMED_OUT
Variants
InitializedUnspecified = 0
A link has just been initialized
VerificationStarted = 1
A link has just started being verified
VerificationError = 2
A link has errored during the verification process
VerificationSuccess = 3
A link has being verified successfully
TimedOut = 4
A link has timed out while waiting for the verification
Implementations
Sourceimpl ApplicationLinkState
impl ApplicationLinkState
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of ApplicationLinkState.
Sourcepub fn from_i32(value: i32) -> Option<ApplicationLinkState>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ApplicationLinkState>
Converts an i32 to a ApplicationLinkState, or None if value is not a valid variant.
Sourceimpl ApplicationLinkState
impl ApplicationLinkState
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.
pub fn serialize<S>(v: &i32, serializer: S) -> Result<S::Ok, S::Error>where
S: Serializer,
pub fn deserialize<'de, D>(deserializer: D) -> Result<i32, D::Error>where
D: Deserializer<'de>,