SignatureValueType

Enum SignatureValueType 

#[repr(i32)]
pub enum SignatureValueType { Unspecified = 0, Raw = 1, CosmosDirect = 2, CosmosAmino = 3, EvmPersonalSign = 4, }
SignatureValueType specifies all the possible signature types

Variants



Unspecified = 0

SIGNATURE_VALUE_TYPE_UNSPECIFIED specifies an unknown signing mode and will be rejected



Raw = 1

SIGNATURE_VALUE_TYPE_RAW should be used when the value has been signed as a raw byte array



CosmosDirect = 2

SIGNATURE_VALUE_TYPE_COSMOS_DIRECT should be used when the signed value has been encoded as a Protobuf transaction containing the owner address inside its memo field



CosmosAmino = 3

SIGNATURE_VALUE_TYPE_COSMOS_AMINO should be used when the value has been encoded as an Amino transaction containing the owner address inside its memo field



EvmPersonalSign = 4

SIGNATURE_VALUE_TYPE_EVM_PERSONAL_SIGN should be used when the value has been encoded following the EVM personal_sign specification

Implementations

Source

impl SignatureValueType

pub const fn from_repr(discriminant: i32) -> Option<SignatureValueType>

Try to create Self from the raw representation

Source

impl SignatureValueType

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of SignatureValueType.

pub fn from_i32(value: i32) -> Option<SignatureValueType>

👎Deprecated: Use the TryFrom<i32> implementation instead

Converts an i32 to a SignatureValueType, or None if value is not a valid variant.

Source

impl SignatureValueType

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.

pub fn serialize<S>(v: &i32, serializer: S) -> Result<S::Ok, S::Error>
where S: Serializer,

pub fn deserialize<'de, D>(deserializer: D) -> Result<i32, D::Error>
where D: Deserializer<'de>,