pub struct ApplicationLink {
pub user: String,
pub data: Option<Data>,
pub state: i32,
pub oracle_request: Option<OracleRequest>,
pub result: Option<ApplicationResult>,
pub creation_time: Option<Timestamp>,
pub expiration_time: Option<Timestamp>,
}Expand description
ApplicationLink contains the data of a link to a centralized application
Fields
user: StringUser to which the link is associated
data: Option<Data>Data contains the details of this specific link
state: i32State of the link
oracle_request: Option<OracleRequest>OracleRequest represents the request that has been made to the oracle
result: Option<ApplicationResult>Data coming from the result of the verification. Only available when the state is STATE_SUCCESS
creation_time: Option<Timestamp>CreationTime represents the time in which the link was created
expiration_time: Option<Timestamp>ExpirationTime represents the time in which the link will expire
Implementations
Sourceimpl ApplicationLink
impl ApplicationLink
Sourcepub fn state(&self) -> ApplicationLinkState
pub fn state(&self) -> ApplicationLinkState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: ApplicationLinkState)
pub fn set_state(&mut self, value: ApplicationLinkState)
Sets state to the provided enum value.