pub struct ChainLink {
pub user: String,
pub address: Option<Any>,
pub proof: Option<Proof>,
pub chain_config: Option<ChainConfig>,
pub creation_time: Option<Timestamp>,
}Expand description
ChainLink contains the data representing either an inter- or cross- chain link
Fields
user: StringUser defines the destination profile address to link
address: Option<Any>Address contains the data of the external chain address to be connected with the Desmos profile
proof: Option<Proof>Proof contains the ownership proof of the external chain address
chain_config: Option<ChainConfig>ChainConfig contains the configuration of the external chain
creation_time: Option<Timestamp>CreationTime represents the time in which the link has been created
Implementations