pub struct CosmosMultiSignature {
pub bit_array: Option<CompactBitArray>,
pub signatures: Vec<Any>,
}Expand description
CosmosMultiSignature is the signature data for a multisig public key
Fields
bit_array: Option<CompactBitArray>Bitarray specifies which keys within the multisig are signing
signatures: Vec<Any>Signatures is the signatures of the multi-signature
Implementations