pub struct LinkChainAccountPacketData {
pub source_address: Option<Any>,
pub source_proof: Option<Proof>,
pub source_chain_config: Option<ChainConfig>,
pub destination_address: String,
pub destination_proof: Option<Proof>,
}Expand description
LinkChainAccountPacketData defines the object that should be sent inside a MsgSendPacket when wanting to link an external chain to a Desmos profile using IBC
Fields
source_address: Option<Any>SourceAddress contains the details of the external chain address
source_proof: Option<Proof>SourceProof represents the proof of ownership of the source address
source_chain_config: Option<ChainConfig>SourceChainConfig contains the details of the source chain
destination_address: StringDestinationAddress represents the Desmos address of the profile that should be linked with the external account
destination_proof: Option<Proof>DestinationProof contains the proof of ownership of the DestinationAddress
Implementations