pub struct MsgLinkApplication {
pub sender: String,
pub link_data: Option<Data>,
pub call_data: String,
pub source_port: String,
pub source_channel: String,
pub timeout_height: Option<Height>,
pub timeout_timestamp: u64,
}Expand description
MsgLinkApplication defines a msg to connect a profile with a centralized application account (eg. Twitter, GitHub, etc).
Fields
sender: StringThe sender of the connection request
link_data: Option<Data>LinkData contains the data related to the application to which connect
call_data: StringHex encoded call data that will be sent to the data source in order to verify the link
source_port: StringThe port on which the packet will be sent
source_channel: StringThe channel by which the packet will be sent
timeout_height: Option<Height>Timeout height relative to the current block height. The timeout is disabled when set to 0.
timeout_timestamp: u64Timeout timestamp (in nanoseconds) relative to the current block timestamp. The timeout is disabled when set to 0.
Implementations