pub struct MsgSetDefaultExternalAddress {
pub chain_name: String,
pub target: String,
pub signer: String,
}Expand description
MsgSetDefaultExternalAddress represents the message used to set a default address for a specific chain
Fields
chain_name: StringName of the chain for which to set the default address
target: StringAddress to be set as the default one
signer: StringUser signing the message
Implementations