pub struct MsgUnlinkApplication {
pub application: String,
pub username: String,
pub signer: String,
}Expand description
MsgUnlinkApplication defines a msg to delete an application link from a user profile
Fields
application: StringApplication represents the name of the application to unlink
username: StringUsername represents the username inside the application to unlink
signer: StringSigner represents the Desmos account to which the application should be unlinked
Implementations