pub struct MsgUnlinkChainAccount {
pub owner: String,
pub chain_name: String,
pub target: String,
}Expand description
MsgUnlinkChainAccount represents a message to unlink an account from a profile.
Fields
owner: StringOwner represents the Desmos profile from which to remove the link
chain_name: StringChainName represents the name of the chain to which the link to remove is associated
target: StringTarget represents the external address to be removed
Implementations