pub struct OracleParams {
pub script_id: u64,
pub ask_count: u64,
pub min_count: u64,
pub prepare_gas: u64,
pub execute_gas: u64,
pub fee_amount: Vec<Coin>,
}Expand description
OracleParams defines the parameters related to the oracle that will be used to verify the ownership of a centralized application account by a Desmos profile
Fields
script_id: u64ScriptID represents the ID of the oracle script to be called to verify the data
ask_count: u64AskCount represents the number of oracles to which ask to verify the data
min_count: u64MinCount represents the minimum count of oracles that should complete the verification successfully
prepare_gas: u64PrepareGas represents the amount of gas to be used during the preparation stage of the oracle script
execute_gas: u64ExecuteGas represents the amount of gas to be used during the execution of the oracle script
fee_amount: Vec<Coin>FeeAmount represents the amount of fees to be payed in order to execute the oracle script
Implementations