pub struct OracleRequest {
pub id: u64,
pub oracle_script_id: u64,
pub call_data: Option<CallData>,
pub client_id: String,
}Expand description
OracleRequest represents a generic oracle request used to verify the ownership of a centralized application account
Fields
id: u64ID is the ID of the request
oracle_script_id: u64OracleScriptID is ID of an oracle script
call_data: Option<CallData>CallData contains the data used to perform the oracle request
client_id: StringClientID represents the ID of the client that has called the oracle script
Implementations