pub struct Profile {
pub account: Option<Any>,
pub dtag: String,
pub nickname: String,
pub bio: String,
pub pictures: Option<Pictures>,
pub creation_date: Option<Timestamp>,
}Expand description
Profile represents a generic first on Desmos, containing the information of a single user
Fields
account: Option<Any>Account represents the base Cosmos account associated with this profile
dtag: StringDTag represents the unique tag of this profile
nickname: StringNickname contains the custom human readable name of the profile
bio: StringBio contains the biography of the profile
pictures: Option<Pictures>Pictures contains the data about the pictures associated with he profile
creation_date: Option<Timestamp>CreationTime represents the time in which the profile has been created
Implementations