pub struct QueryApplicationLinkOwnersRequest {
pub application: String,
pub username: String,
pub pagination: Option<PageRequest>,
}Expand description
QueryApplicationLinkOwnersRequest contains the data of the request that can be used to get application link owners
Fields
application: String(Optional) Application name to search link owners of. If not specified, all links stored will be searched instead.
username: String(Optional) Username to search for. This will only be used if the application is specified as well
pagination: Option<PageRequest>Pagination defines an optional pagination for the request
Implementations
Sourceimpl QueryApplicationLinkOwnersRequest
impl QueryApplicationLinkOwnersRequest
pub const TYPE_URL: &'static str = "/desmos.profiles.v3.QueryApplicationLinkOwnersRequest"
pub fn query( self, querier: &QuerierWrapper<'_, impl CustomQuery>, ) -> StdResult<QueryApplicationLinkOwnersResponse>
pub fn mock_response<T: MockableQuerier>( querier: &mut T, response: QueryApplicationLinkOwnersResponse, )
pub fn mock_failed_response<T: MockableQuerier>(querier: &mut T, error: String)