pub struct QueryChainLinkOwnersRequest {
pub chain_name: String,
pub target: String,
pub pagination: Option<PageRequest>,
}Expand description
QueryChainLinkOwnersRequest contains the data of the request that can be used to get chain link owners
Fields
chain_name: String(Optional) Chain name to search link owners of. If not specified, all links stored will be searched instead.
target: String(Optional) External address to search for. This will only be used if the chain name is specified as well
pagination: Option<PageRequest>Pagination defines an optional pagination for the request
Implementations
Sourceimpl QueryChainLinkOwnersRequest
impl QueryChainLinkOwnersRequest
pub const TYPE_URL: &'static str = "/desmos.profiles.v3.QueryChainLinkOwnersRequest"
pub fn query( self, querier: &QuerierWrapper<'_, impl CustomQuery>, ) -> StdResult<QueryChainLinkOwnersResponse>
pub fn mock_response<T: MockableQuerier>( querier: &mut T, response: QueryChainLinkOwnersResponse, )
pub fn mock_failed_response<T: MockableQuerier>(querier: &mut T, error: String)