QueryChainLinksRequest

Struct QueryChainLinksRequest 

pub struct QueryChainLinksRequest {
    pub user: String,
    pub chain_name: String,
    pub target: String,
    pub pagination: Option<PageRequest>,
}
QueryChainLinksRequest represents the request that should be used in order to retrieve the link associated with the provided user, for the given chain and having the given target address

Fields

user: String

(optional) User represents the Desmos address of the user to which search the link for

chain_name: String

(optional) ChainName contains the name of the chain to which search the link for. Used only if user is also set

target: String

(optional) Target must contain the external address to which query the link for. Used only if chain name is also set

pagination: Option<PageRequest>

Pagination defines an optional pagination for the request

Implementations

Source

impl QueryChainLinksRequest

pub const TYPE_URL: &'static str = "/desmos.profiles.v3.QueryChainLinksRequest"

pub fn query( self, querier: &QuerierWrapper<'_, impl CustomQuery>, ) -> StdResult<QueryChainLinksResponse>

pub fn mock_response<T: MockableQuerier>( querier: &mut T, response: QueryChainLinksResponse, )

pub fn mock_failed_response<T: MockableQuerier>(querier: &mut T, error: String)