pub struct SingleSignature {
pub value_type: i32,
pub signature: Vec<u8>,
}Expand description
SingleSignature is the signature data for a single signer
Fields
value_type: i32Type represents the type of the signature value
signature: Vec<u8>Signature is the raw signature bytes
Implementations
Sourceimpl SingleSignature
impl SingleSignature
Sourcepub fn value_type(&self) -> SignatureValueType
pub fn value_type(&self) -> SignatureValueType
Returns the enum value of value_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_value_type(&mut self, value: SignatureValueType)
pub fn set_value_type(&mut self, value: SignatureValueType)
Sets value_type to the provided enum value.