pub struct MsgAddReaction {
pub subspace_id: u64,
pub post_id: u64,
pub value: Option<Any>,
pub user: String,
}Expand description
MsgAddReaction represents the message to be used to add a post reaction
Fields
subspace_id: u64Id of the subspace inside which the post to react to is
post_id: u64Id of the post to react to
value: Option<Any>Value of the reaction
user: StringUser reacting to the post
Implementations