pub struct MsgAddRegisteredReaction {
pub subspace_id: u64,
pub shorthand_code: String,
pub display_value: String,
pub user: String,
}Expand description
MsgAddRegisteredReaction represents the message to be used to register a new supported reaction
Fields
subspace_id: u64Id of the subspace inside which this reaction should be registered
shorthand_code: StringShorthand code of the reaction
display_value: StringDisplay value of the reaction
user: StringUser adding the supported reaction
Implementations