pub struct MsgRemoveReaction {
pub subspace_id: u64,
pub post_id: u64,
pub reaction_id: u32,
pub user: String,
}Expand description
MsgRemoveReaction represents the message to be used to remove an existing reaction from a post
Fields
subspace_id: u64Id of the subspace inside which the reaction to remove is
post_id: u64Id of the post from which to remove the reaction
reaction_id: u32Id of the reaction to be removed
user: StringUser removing the reaction
Implementations