pub struct MsgRemoveRegisteredReaction {
pub subspace_id: u64,
pub registered_reaction_id: u32,
pub user: String,
}Expand description
MsgRemoveRegisteredReaction represents the message to be used to remove an existing registered reaction
Fields
subspace_id: u64Id of the subspace from which to remove the registered reaction
registered_reaction_id: u32Id of the registered reaction to be removed
user: StringUser removing the registered reaction
Implementations