pub struct QueryReactionsRequest {
pub subspace_id: u64,
pub post_id: u64,
pub user: String,
pub pagination: Option<PageRequest>,
}Expand description
QueryReactionsRequest is the request type for the Query/Reactions RPC method
Fields
subspace_id: u64Id of the subspace that contains the post to query the reactions for
post_id: u64Post id to query the reactions for
user: String(optional) User to query the reactions for. This is going to be used only if a post id is specified as well.
pagination: Option<PageRequest>pagination defines an optional pagination for the request.
Implementations
Sourceimpl QueryReactionsRequest
impl QueryReactionsRequest
pub const TYPE_URL: &'static str = "/desmos.reactions.v1.QueryReactionsRequest"
pub fn query( self, querier: &QuerierWrapper<'_, impl CustomQuery>, ) -> StdResult<QueryReactionsResponse>
pub fn mock_response<T: MockableQuerier>( querier: &mut T, response: QueryReactionsResponse, )
pub fn mock_failed_response<T: MockableQuerier>(querier: &mut T, error: String)