pub struct MsgBlockUser {
pub blocker: String,
pub blocked: String,
pub reason: String,
pub subspace_id: u64,
}Expand description
MsgBlockUser represents a message to block another user specifying an optional reason.
Fields
blocker: StringAddress of the user blocking the other user
blocked: StringAddress of the user that should be blocked
reason: String(optional) Reason why the user has been blocked
subspace_id: u64Id of the subspace inside which the user should be blocked
Implementations