pub struct MsgCreateRelationship {
pub signer: String,
pub counterparty: String,
pub subspace_id: u64,
}Expand description
MsgCreateRelationship represents a message to create a relationship between two users on a specific subspace.
Fields
signer: StringUser creating the relationship
counterparty: StringCounterparty of the relationship (i.e. user to be followed)
subspace_id: u64Subspace id inside which the relationship will be valid
Implementations