pub struct MsgUnblockUser {
pub blocker: String,
pub blocked: String,
pub subspace_id: u64,
}Expand description
MsgUnblockUser represents a message to unblock a previously blocked user.
Fields
blocker: StringAddress of the user that blocked another user
blocked: StringAddress of the user that should be unblocked
subspace_id: u64Id of the subspace inside which the user should be unblocked
Implementations