pub struct QueryBlocksRequest {
pub subspace_id: u64,
pub blocker: String,
pub blocked: String,
pub pagination: Option<PageRequest>,
}Expand description
QueryBlocksRequest is the request type for the Query/Blocks RPC endpoint
Fields
subspace_id: u64subspace to query the blocks for
blocker: Stringoptional address of the blocker to query the blocks for
blocked: Stringoptional address of the blocked user to query the block for (used only if the blocker is provided)
pagination: Option<PageRequest>pagination defines an optional pagination for the request.
Implementations
Sourceimpl QueryBlocksRequest
impl QueryBlocksRequest
pub const TYPE_URL: &'static str = "/desmos.relationships.v1.QueryBlocksRequest"
pub fn query( self, querier: &QuerierWrapper<'_, impl CustomQuery>, ) -> StdResult<QueryBlocksResponse>
pub fn mock_response<T: MockableQuerier>( querier: &mut T, response: QueryBlocksResponse, )
pub fn mock_failed_response<T: MockableQuerier>(querier: &mut T, error: String)