pub struct QueryRelationshipsRequest {
pub subspace_id: u64,
pub user: String,
pub counterparty: String,
pub pagination: Option<PageRequest>,
}Expand description
QueryRelationshipsRequest is the request type for the Query/Relationships RPC method.
Fields
subspace_id: u64subspace to query the relationships for
user: Stringoptional address of the user for which to query the relationships
counterparty: Stringoptional address of the counterparty of the relationships (used only if the user is provided)
pagination: Option<PageRequest>pagination defines an optional pagination for the request.
Implementations
Sourceimpl QueryRelationshipsRequest
impl QueryRelationshipsRequest
pub const TYPE_URL: &'static str = "/desmos.relationships.v1.QueryRelationshipsRequest"
pub fn query( self, querier: &QuerierWrapper<'_, impl CustomQuery>, ) -> StdResult<QueryRelationshipsResponse>
pub fn mock_response<T: MockableQuerier>( querier: &mut T, response: QueryRelationshipsResponse, )
pub fn mock_failed_response<T: MockableQuerier>(querier: &mut T, error: String)