pub struct UserBlock {
pub blocker: String,
pub blocked: String,
pub reason: String,
pub subspace_id: u64,
}Expand description
UserBlock represents the fact that the Blocker has blocked the given Blocked user.
Fields
blocker: StringBlocker represents the address of the user blocking another one
blocked: StringBlocked represents the address of the blocked user
reason: StringReason represents the optional reason the user has been blocked for.
subspace_id: u64SubspaceID represents the ID of the subspace inside which the user should be blocked
Implementations