pub struct MsgAddReason {
pub subspace_id: u64,
pub title: String,
pub description: String,
pub signer: String,
}Expand description
MsgAddReason represents the message to be used when adding a new supported reason
Fields
subspace_id: u64Id of the subspace for which to add the reason
title: StringTitle of the reason
description: String(optional) Extended description of the reason and the cases it applies to
signer: StringAddress of the user adding the supported reason
Implementations