pub struct Reason {
pub subspace_id: u64,
pub id: u32,
pub title: String,
pub description: String,
}Expand description
Reason contains the data about a reporting reason
Fields
subspace_id: u64Id of the subspace for which this reason is valid
id: u32Id of the reason inside the subspace
title: StringTitle of the reason
description: String(optional) Extended description of the reason and the cases it applies to
Implementations