pub struct StandardReason {
pub id: u32,
pub title: String,
pub description: String,
}Expand description
StandardReason contains the data of a standard reason that can be picked and used from different subspaces
Fields
id: u32Id of the reason inside the subspace
title: StringTitle of the reason
description: String(optional) Extended description of the reason and the cases it applies to
Implementations