pub enum Permission {
EditSubspace,
DeleteSubspace,
ManageSections,
ManageGroups,
SetPermissions,
Everything,
Write,
InteractWithContent,
EditOwnContent,
ModerateContent,
}Expand description
Represents the permission to perform operations inside the subspace.
Variants
EditSubspace
Allows to change the information of the subspace.
DeleteSubspace
Allows users to delete the subspace.
ManageSections
Allows users to manage a subspace sections.
ManageGroups
Allows users to manage user groups and members.
SetPermissions
Allows users to set other users’ permissions (except Permission::SetPermissions`).
This includes managing user groups and the associated permissions.
Everything
Allows to do everything. This should usually be reserved only to the owner (which has it by default).
Write
Identifies users that can create content inside the subspace.
InteractWithContent
Allows users to interact with content inside the subspace (eg. polls).
EditOwnContent
Allows users to edit their own content inside the subspace.
ModerateContent
Allows users to moderate other user’s content.