pub struct Grant {
pub subspace_id: u64,
pub granter: String,
pub grantee: Option<Any>,
pub allowance: Option<Any>,
}Expand description
Grant represents a grant to a user or a group
Fields
subspace_id: u64Id of the subspace inside which the user was granted the allowance
granter: StringAddress of the user that granted the allowance
grantee: Option<Any>Target to which the allowance has been granted
allowance: Option<Any>Allowance can be any allowance type implementing the FeeAllowanceI interface
Implementations