pub struct MsgAddUserToUserGroup {
pub subspace_id: u64,
pub group_id: u32,
pub user: String,
pub signer: String,
}Expand description
MsgAddUserToUserGroup represents the message used to add a user to a user group
Fields
subspace_id: u64Id of the subspace inside which the group is
group_id: u32Id of the group to which to add the user
user: StringUser to be added to the group
signer: StringUser signing the message
Implementations