pub struct MsgCreateSection {
pub subspace_id: u64,
pub name: String,
pub description: String,
pub parent_id: u32,
pub creator: String,
}Expand description
MsgCreateSection represents the message to be used when creating a subspace section
Fields
subspace_id: u64Id of the subspace inside which the section will be placed
name: StringName of the section to be created
description: String(optional) Description of the section
parent_id: u32(optional) Id of the parent section
creator: StringUser creating the section
Implementations