pub struct MsgCreateSubspace {
pub name: String,
pub description: String,
pub owner: String,
pub creator: String,
}Expand description
MsgCreateSubspace represents the message used to create a subspace
Fields
name: StringName of the subspace
description: String(optional) Description of the subspace
owner: String(optional) Owner of this subspace. If not specified, the creator will be the default owner.
creator: StringAddress creating the subspace
Implementations