pub struct MsgCreateUserGroup {
pub subspace_id: u64,
pub section_id: u32,
pub name: String,
pub description: String,
pub default_permissions: Vec<String>,
pub initial_members: Vec<String>,
pub creator: String,
}Expand description
MsgCreateUserGroup represents the message used to create a user group
Fields
subspace_id: u64Id of the subspace inside which the group will be created
section_id: u32(optional) Id of the section inside which the group will be created
name: StringName of the group
description: String(optional) Description of the group
default_permissions: Vec<String>Default permissions to be applied to the group
initial_members: Vec<String>Initial members to be put inside the group
creator: StringCreator of the group
Implementations