pub struct MsgDeleteSection {
pub subspace_id: u64,
pub section_id: u32,
pub signer: String,
}Expand description
MsgDeleteSection represents the message to be used when deleting a section
Fields
subspace_id: u64Id of the subspace inside which the section to be deleted is
section_id: u32Id of the section to delete
signer: StringUser deleting the section
Implementations