pub struct MsgDeleteUserGroup {
pub subspace_id: u64,
pub group_id: u32,
pub signer: String,
}Expand description
MsgDeleteUserGroup represents the message used to delete a user group
Fields
subspace_id: u64Id of the subspace inside which the group to delete is
group_id: u32Id of the group to be deleted
signer: StringUser deleting the group
Implementations