pub struct MsgEditSection {
pub subspace_id: u64,
pub section_id: u32,
pub name: String,
pub description: String,
pub editor: String,
}Expand description
MsgEditSection represents the message to be used when editing a subspace section
Fields
subspace_id: u64Id of the subspace inside which the section to be edited is
section_id: u32Id of the section to be edited
name: String(optional) New name of the section
description: String(optional) New description of the section
editor: StringUser editing the section
Implementations