pub struct MsgEditUserGroup {
pub subspace_id: u64,
pub group_id: u32,
pub name: String,
pub description: String,
pub signer: String,
}Expand description
MsgEditUserGroup represents the message used to edit a user group
Fields
subspace_id: u64Id of the subspace inside which the group to be edited is
group_id: u32Id of the group to be edited
name: String(optional) New name of the group
description: String(optional) New description of the group
signer: StringUser editing the group
Implementations