pub struct MsgGrantAllowance {
pub subspace_id: u64,
pub granter: String,
pub grantee: Option<Any>,
pub allowance: Option<Any>,
}Expand description
MsgGrantAllowance adds grants for the grantee to spend up allowance of fees from the treasury inside the given subspace
Fields
subspace_id: u64Id of the subspace inside which where the allowance should be granted
granter: StringAddress of the user granting the allowance
grantee: Option<Any>Target being granted the allowance
allowance: Option<Any>Allowance can be any allowance type that implements AllowanceI
Implementations