pub struct MsgMoveSection {
pub subspace_id: u64,
pub section_id: u32,
pub new_parent_id: u32,
pub signer: String,
}Expand description
MsgMoveSection represents the message to be used when moving a section to another parent
Fields
subspace_id: u64Id of the subspace inside which the section lies
section_id: u32Id of the section to be moved
new_parent_id: u32Id of the new parent
signer: StringSigner of the message
Implementations