pub struct MsgMoveUserGroup {
pub subspace_id: u64,
pub group_id: u32,
pub new_section_id: u32,
pub signer: String,
}Expand description
MsgMoveUserGroup represents the message used to move one user group from a section to another
Fields
subspace_id: u64Id of the subspace inside which the group to move is
group_id: u32Id of the group to be moved
new_section_id: u32Id of the new section where to move the group
signer: StringUser signing the message
Implementations