pub struct MsgRemoveUserFromUserGroup {
pub subspace_id: u64,
pub group_id: u32,
pub user: String,
pub signer: String,
}Expand description
MsgRemoveUserFromUserGroup represents the message used to remove a user from a user group
Fields
subspace_id: u64Id of the subspace inside which the group to remove the user from is
group_id: u32Id of the group from which to remove the user
user: StringUser to be removed from the group
signer: StringUser signing the message
Implementations