pub struct MsgRevokeAllowance {
pub subspace_id: u64,
pub granter: String,
pub grantee: Option<Any>,
}Expand description
MsgRevokeAllowance removes any existing allowance to the grantee inside the subspace
Fields
subspace_id: u64If of the subspace inside which the allowance to be deleted is
granter: StringAddress of the user that created the allowance
grantee: Option<Any>Target being revoked the allowance
Implementations