pub struct MsgRevokeTreasuryAuthorization {
pub subspace_id: u64,
pub granter: String,
pub grantee: String,
pub msg_type_url: String,
}Expand description
MsgRevokeTreasuryAuthorization revokes an existing treasury authorization from a user
Fields
subspace_id: u64Id of the subspace from which the authorization should be revoked
granter: StringAddress of the user revoking the treasury authorization
grantee: StringAddress of the user who is being revoked the treasury authorization
msg_type_url: StringType url of the authorized message which is being revoked
Implementations