pub struct MsgSetUserGroupPermissions {
pub subspace_id: u64,
pub group_id: u32,
pub permissions: Vec<String>,
pub signer: String,
}Expand description
MsgSetUserGroupPermissions represents the message used to set the permissions of a user group
Fields
subspace_id: u64Id of the subspace inside which the group is
group_id: u32Id of the group for which to set the new permissions
permissions: Vec<String>New permissions to be set to the group
signer: StringUser setting the new permissions
Implementations