pub struct MsgSetUserPermissions {
pub subspace_id: u64,
pub section_id: u32,
pub user: String,
pub permissions: Vec<String>,
pub signer: String,
}Expand description
MsgSetUserPermissions represents the message used to set the permissions of a specific user
Fields
subspace_id: u64Id of the subspace inside which to set the permissions
section_id: u32Id of the section for which to set the permissions
user: StringUser for which to set the permissions
permissions: Vec<String>Permissions to be set to the user
signer: StringUser signing the message
Implementations