pub struct MsgUpdateSubspaceFeeTokens {
pub subspace_id: u64,
pub additional_fee_tokens: Vec<Coin>,
pub authority: String,
}Expand description
MsgUpdateSubspaceFeeTokens represents the message to be used to update the accepted fee tokens inside a given subspace, using an on-chain governance proposal
Since: Desmos 6.0.0
Fields
subspace_id: u64Id of the subspace where the list of allowed fee tokens will be updated
additional_fee_tokens: Vec<Coin>List of tokens allowed to be fee tokens inside the given subspace, represented as their gas prices
authority is the address that controls the module (defaults to x/gov unless overwritten).
Implementations