pub struct QueryGroupAllowancesRequest {
pub subspace_id: u64,
pub group_id: u32,
pub pagination: Option<PageRequest>,
}Expand description
QueryGroupAllowancesRequest is the request type for the Query/GroupAllowances RPC method
Fields
subspace_id: u64Id of the subspace for which to get the grant(s)
group_id: u32(optional) Address of the user group that was granted the allowance(s)
pagination: Option<PageRequest>pagination defines an pagination for the request
Implementations
Sourceimpl QueryGroupAllowancesRequest
impl QueryGroupAllowancesRequest
pub const TYPE_URL: &'static str = "/desmos.subspaces.v3.QueryGroupAllowancesRequest"
pub fn query( self, querier: &QuerierWrapper<'_, impl CustomQuery>, ) -> StdResult<QueryGroupAllowancesResponse>
pub fn mock_response<T: MockableQuerier>( querier: &mut T, response: QueryGroupAllowancesResponse, )
pub fn mock_failed_response<T: MockableQuerier>(querier: &mut T, error: String)