pub struct QueryUserAllowancesRequest {
pub subspace_id: u64,
pub grantee: String,
pub pagination: Option<PageRequest>,
}Expand description
QueryUserAllowancesRequest is the request type for the Query/UserAllowances RPC method
Fields
subspace_id: u64Id of the subspace for which to get the grant(s)
grantee: String(Optional) Address of the user that was granted an allowance
pagination: Option<PageRequest>pagination defines an pagination for the request
Implementations
Sourceimpl QueryUserAllowancesRequest
impl QueryUserAllowancesRequest
pub const TYPE_URL: &'static str = "/desmos.subspaces.v3.QueryUserAllowancesRequest"
pub fn query( self, querier: &QuerierWrapper<'_, impl CustomQuery>, ) -> StdResult<QueryUserAllowancesResponse>
pub fn mock_response<T: MockableQuerier>( querier: &mut T, response: QueryUserAllowancesResponse, )
pub fn mock_failed_response<T: MockableQuerier>(querier: &mut T, error: String)