pub struct QueryUserPermissionsRequest {
pub subspace_id: u64,
pub section_id: u32,
pub user: String,
}Expand description
QueryUserPermissionsRequest is the request type for the Query/UserPermissions RPC method
Fields
subspace_id: u64Id of the subspace to query the permissions for
section_id: u32Id of the section to query the permissions for
user: StringAddress of the user to query the permissions for
Implementations
Sourceimpl QueryUserPermissionsRequest
impl QueryUserPermissionsRequest
pub const TYPE_URL: &'static str = "/desmos.subspaces.v3.QueryUserPermissionsRequest"
pub fn query( self, querier: &QuerierWrapper<'_, impl CustomQuery>, ) -> StdResult<QueryUserPermissionsResponse>
pub fn mock_response<T: MockableQuerier>( querier: &mut T, response: QueryUserPermissionsResponse, )
pub fn mock_failed_response<T: MockableQuerier>(querier: &mut T, error: String)