pub struct Section {
pub subspace_id: u64,
pub id: u32,
pub parent_id: u32,
pub name: String,
pub description: String,
}Expand description
Section contains the data of a single subspace section
Fields
subspace_id: u64Id of the subspace inside which the section exists
id: u32Unique id of the section within the subspace
parent_id: u32(optional) Id of the parent section
name: StringName of the section within the subspace
description: String(optional) Description of the section
Implementations