pub struct Subspace {
pub id: u64,
pub name: String,
pub description: String,
pub treasury: String,
pub owner: String,
pub creator: String,
pub creation_time: Option<Timestamp>,
pub additional_fee_tokens: Vec<Coin>,
}Expand description
Subspace contains all the data of a Desmos subspace
Fields
id: u64Unique id that identifies the subspace
name: StringHuman-readable name of the subspace
description: StringOptional description of this subspace
treasury: StringRepresents the treasury account that is associated with the subspace
owner: StringAddress of the user that owns the subspace
creator: StringAddress of the subspace creator
creation_time: Option<Timestamp>the creation time of the subspace
additional_fee_tokens: Vec<Coin>List of fee token denoms with default minimum gas prices allowed inside the subspace
Implementations