pub struct UserGroup {
pub subspace_id: u64,
pub section_id: u32,
pub id: u32,
pub name: String,
pub description: String,
pub permissions: Vec<String>,
}Expand description
UserGroup represents a group of users
Fields
subspace_id: u64ID of the subspace inside which this group exists
section_id: u32(optional) Id of the section inside which this group is valid
id: u32Unique id that identifies the group
name: StringHuman-readable name of the user group
description: StringOptional description of this group
permissions: Vec<String>Permissions that will be granted to all the users part of this group
Implementations