Contains the messages that can be sent to the chain to interact with the x/tokenfactory module.
Structs
- Tokenfactory
Msg - TokenfactoryMsg is the builder to generate Desmos x/tokenfactory messages.
Contains the messages that can be sent to the chain to interact with the x/tokenfactory module.