TokenfactoryQuerier

Struct TokenfactoryQuerier 

pub struct TokenfactoryQuerier<'a> { /* private fields */ }
Querier allows to query data from the Desmos x/tokenfactory module.

Implementations

Source

impl<'a> TokenfactoryQuerier<'a>

pub fn new(querier: &'a QuerierWrapper<'a, Empty>) -> Self

Create a new TokenfactoryQuerier

Example
use cosmwasm_std::{DepsMut, MessageInfo};
use desmos_bindings::tokenfactory::querier::TokenfactoryQuerier;

pub fn contract_action(deps: DepsMut, _: MessageInfo) {
    let querier = TokenfactoryQuerier::new(&deps.querier);
    let response = querier.query_subspace_denoms(1);
}
Source

impl<'a> TokenfactoryQuerier<'a>

pub fn query_subspace_denoms( &self, subspace_id: u64, ) -> StdResult<QuerySubspaceDenomsResponse>

Queries all the denoms created by the given subspace.

  • subspace_id - Id of the subspace to query the managed denoms for.