pub struct MsgBurn {
pub subspace_id: u64,
pub sender: String,
pub amount: Option<Coin>,
}Expand description
MsgBurn represents the message to be used to burn subspace tokens from treasury account
Since: Desmos 6.0.0
Fields
subspace_id: u64Id of the subspace which manages the denom
sender: StringAddress of user having the permission to manage subspace denoms
amount: Option<Coin>Amount of the burning subspace tokens
Implementations