pub struct MsgCreateDenom {
pub subspace_id: u64,
pub sender: String,
pub subdenom: String,
}Expand description
MsgCreateDenom represents the message to be used to create a denom for subspace
Since: Desmos 6.0.0
Fields
subspace_id: u64Id of the subspace which manages the denom
sender: StringAddress of user having the permission to manage subspace denoms
subdenom: StringSubdenom name of the creating denom It can be up to 44 “alphanumeric” characters long
Implementations