pub struct MsgMint {
pub subspace_id: u64,
pub sender: String,
pub amount: Option<Coin>,
}Expand description
MsgMint represents the message to be used to mint subspace tokens to treasury account
Since: Desmos 6.0.0
Fields
subspace_id: u64Id of the subspace which manages the denom
sender: StringAddress of user having the permission to manage subspace denoms
amount: Option<Coin>Amount of the minting subspace tokens
Implementations