pub struct MsgSetDenomMetadata {
pub subspace_id: u64,
pub sender: String,
pub metadata: Option<Metadata>,
}Expand description
MsgSetDenomMetadata represents the message to be used to set the subspace token’s bank metadata
Since: Desmos 6.0.0
Fields
subspace_id: u64Id of the subspace which manages the denom
sender: StringAddress of user having the permission to manage subspace denoms
metadata: Option<Metadata>Metadata of the denom
Implementations