Contains utilities, structs and enum to interact with the Desmos x/posts module.
Modules
- mocks
- Contains useful mocks of the Desmos x/posts module’s types made to be used in any test.
- msg
- Contains the messages that can be sent to the chain to interact with the x/posts module.
- querier
- Contains the querier that can be used to query data related to the x/posts module.
- types
- Contains the types definitions of x/posts.