#[repr(i32)]pub enum SignatureValueType {
Unspecified = 0,
Raw = 1,
CosmosDirect = 2,
CosmosAmino = 3,
EvmPersonalSign = 4,
}Expand description
SignatureValueType specifies all the possible signature types
Variants
Unspecified = 0
SIGNATURE_VALUE_TYPE_UNSPECIFIED specifies an unknown signing mode and will be rejected
Raw = 1
SIGNATURE_VALUE_TYPE_RAW should be used when the value has been signed as a raw byte array
CosmosDirect = 2
SIGNATURE_VALUE_TYPE_COSMOS_DIRECT should be used when the signed value has been encoded as a Protobuf transaction containing the owner address inside its memo field
CosmosAmino = 3
SIGNATURE_VALUE_TYPE_COSMOS_AMINO should be used when the value has been encoded as an Amino transaction containing the owner address inside its memo field
EvmPersonalSign = 4
SIGNATURE_VALUE_TYPE_EVM_PERSONAL_SIGN should be used when the value has been encoded following the EVM personal_sign specification
Implementations
Sourceimpl SignatureValueType
impl SignatureValueType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.
pub fn serialize<S>(v: &i32, serializer: S) -> Result<S::Ok, S::Error>where
S: Serializer,
pub fn deserialize<'de, D>(deserializer: D) -> Result<i32, D::Error>where
D: Deserializer<'de>,