pub struct ReactionsMsg {}Expand description
ReactionsMsg is the builder to generate Desmos x/reactions messages.
Implementations
Sourceimpl ReactionsMsg
impl ReactionsMsg
Sourcepub fn add_reaction(
subspace_id: u64,
post_id: u64,
value: ReactionValue,
user: Addr,
) -> MsgAddReaction
pub fn add_reaction( subspace_id: u64, post_id: u64, value: ReactionValue, user: Addr, ) -> MsgAddReaction
Creates a new instance of MsgAddReaction.
subspace_id- Id of the subspace inside which the post to react to is.post_id- Id of the post to react to.value- Value of the reaction.user- User reacting to the post.
Sourcepub fn remove_reaction(
subspace_id: u64,
post_id: u64,
reaction_id: u32,
user: Addr,
) -> MsgRemoveReaction
pub fn remove_reaction( subspace_id: u64, post_id: u64, reaction_id: u32, user: Addr, ) -> MsgRemoveReaction
Creates a new instance of MsgRemoveReaction.
subspace_id- Id of the subspace inside which the reaction to remove is.post_id- Id of the post from which to remove the reaction.reaction_id- Id of the reaction to be removed.user- User removing the reaction.
Sourcepub fn add_registered_reaction(
subspace_id: u64,
shorthand_code: &str,
display_value: &str,
user: Addr,
) -> MsgAddRegisteredReaction
pub fn add_registered_reaction( subspace_id: u64, shorthand_code: &str, display_value: &str, user: Addr, ) -> MsgAddRegisteredReaction
Creates a new instance of MsgAddRegisteredReaction.
subspace_id- Id of the subspace inside which this reaction should be registered.shorthand_code- Shorthand code of the reaction.display_value- Display value of the reaction.user- User adding the supported reaction.
Sourcepub fn edit_registered_reaction(
subspace_id: u64,
registered_reaction_id: u32,
shorthand_code: &str,
display_value: &str,
user: Addr,
) -> MsgEditRegisteredReaction
pub fn edit_registered_reaction( subspace_id: u64, registered_reaction_id: u32, shorthand_code: &str, display_value: &str, user: Addr, ) -> MsgEditRegisteredReaction
Creates a new instance of MsgEditRegisteredReaction.
subspace_id- Id of the subspace inside which the reaction to edit is.registered_reaction_id- Id of the registered reaction to edit.shorthand_code- New shorthand code to be set.display_value- Display value to be set.user- User editing the registered reaction.
Sourcepub fn remove_registered_reaction(
subspace_id: u64,
registered_reaction_id: u32,
user: Addr,
) -> MsgRemoveRegisteredReaction
pub fn remove_registered_reaction( subspace_id: u64, registered_reaction_id: u32, user: Addr, ) -> MsgRemoveRegisteredReaction
Creates a new instance of MsgRemoveRegisteredReaction.
subspace_id- Id of the registered reaction to be removed.registered_reaction_id- Id of the registered reaction to be removed.user- User removing the registered reaction.
Sourcepub fn set_reactions_params(
subspace_id: u64,
registered_reaction: Option<RegisteredReactionValueParams>,
free_text: Option<FreeTextValueParams>,
user: Addr,
) -> MsgSetReactionsParams
pub fn set_reactions_params( subspace_id: u64, registered_reaction: Option<RegisteredReactionValueParams>, free_text: Option<FreeTextValueParams>, user: Addr, ) -> MsgSetReactionsParams
Creates a new instance of MsgSetReactionsParams.
subspace_id- Id of the subspace for which to set the params.registered_reaction- Params related toFreeTextValue.free_text- Params related toRegisteredReactionValue.user- User setting the params.