pub struct RelationshipsMsg {}Expand description
RelationshipsMsg is the builder to generate Desmos x/relationships messages.
Implementations
Sourceimpl RelationshipsMsg
impl RelationshipsMsg
Sourcepub fn create_relationship(
signer: Addr,
counterparty: Addr,
subspace_id: u64,
) -> MsgCreateRelationship
pub fn create_relationship( signer: Addr, counterparty: Addr, subspace_id: u64, ) -> MsgCreateRelationship
Creates a new instance of MsgCreateRelationship.
signer- Address of who wants to create the relationship.counterparty- Address of the counterparty.subspace_id- Subspace in which will be created the relationship.
Sourcepub fn delete_relationship(
signer: Addr,
counterparty: Addr,
subspace_id: u64,
) -> MsgDeleteRelationship
pub fn delete_relationship( signer: Addr, counterparty: Addr, subspace_id: u64, ) -> MsgDeleteRelationship
Creates a new instance of MsgDeleteRelationship.
signer- Address of who wants to delete the relationship.counterparty- Address of the counterparty.subspace_id- Subspace in which will be deleted the relationship.
Sourcepub fn block_user(
blocker: Addr,
blocked: Addr,
reason: &str,
subspace_id: u64,
) -> MsgBlockUser
pub fn block_user( blocker: Addr, blocked: Addr, reason: &str, subspace_id: u64, ) -> MsgBlockUser
Creates a new instance of MsgBlockUser.
blocker- Address of wants to create the block.blocked- Address of the user that will be blocker fromblocker.reason- Reason of the block.subspace_id- Subspace on which will be created the block.
Sourcepub fn unblock_user(
blocker: Addr,
blocked: Addr,
subspace_id: u64,
) -> MsgUnblockUser
pub fn unblock_user( blocker: Addr, blocked: Addr, subspace_id: u64, ) -> MsgUnblockUser
Creates a new instance of MsgUnblockUser.
blocker- Address of who wants to delete the block.blocked- Address of the user that will be unblocked fromblocker.subspace_id- Subspace in which will be deleted the block.