pub enum ReportsMsg {}Expand description
ReportsMsg is the builder to generate Desmos x/reports messages.
Implementations
Sourceimpl ReportsMsg
impl ReportsMsg
Sourcepub fn create_report(
subspace_id: u64,
reasons_ids: Vec<u32>,
message: &str,
reporter: Addr,
target: ReportTarget,
) -> MsgCreateReport
pub fn create_report( subspace_id: u64, reasons_ids: Vec<u32>, message: &str, reporter: Addr, target: ReportTarget, ) -> MsgCreateReport
Creates an instance of MsgCreateReport.
subspace_id- Id of the subspace for which the report should be stored.reasons_ids- Id of the reason this report has been created for.message- Message attached to this report.reporter- Address of the reporter.target- Target of the report.
Sourcepub fn delete_report(
subspace_id: u64,
report_id: u64,
signer: Addr,
) -> MsgDeleteReport
pub fn delete_report( subspace_id: u64, report_id: u64, signer: Addr, ) -> MsgDeleteReport
Creates an instance of MsgDeleteReport.
subspace_id- Id of the subspace that contains the report to be deleted.report_id- Id of the report to be deleted.signer- Address of the user deleting the report.
Sourcepub fn support_standard_reason(
subspace_id: u64,
standard_reason_id: u32,
signer: Addr,
) -> MsgSupportStandardReason
pub fn support_standard_reason( subspace_id: u64, standard_reason_id: u32, signer: Addr, ) -> MsgSupportStandardReason
Creates an instance of MsgSupportStandardReason.
subspace_id- Id of the subspace for which to support the reasonstandard_reason_id- Id of the reason that should be supportedsigner- Address of the user signing the message.
Sourcepub fn add_reason(
subspace_id: u64,
title: &str,
description: &str,
signer: Addr,
) -> MsgAddReason
pub fn add_reason( subspace_id: u64, title: &str, description: &str, signer: Addr, ) -> MsgAddReason
Creates a new instance of MsgAddReason.
subspace_id- Id of the subspace for which to add the reason.title- Title of the reason.description- Extended description of the reason and the cases it applies to.signer- Address of the user adding the supported reason.
Sourcepub fn remove_reason(
subspace_id: u64,
reason_id: u32,
signer: Addr,
) -> MsgRemoveReason
pub fn remove_reason( subspace_id: u64, reason_id: u32, signer: Addr, ) -> MsgRemoveReason
Creates a new instance of MsgRemoveReason.
subspace_id- Id of the subspace from which to remove the reason.reason_id- Id of the reason to be deleted.signer- Address of the user removing the supported reason.