TokenfactoryMsg

Struct TokenfactoryMsg 

pub struct TokenfactoryMsg {}
TokenfactoryMsg is the builder to generate Desmos x/tokenfactory messages.

Implementations

Source

impl TokenfactoryMsg

pub fn create_denom( subspace_id: u64, sender: Addr, subdenom: &str, ) -> MsgCreateDenom

Creates a new instance of MsgCreateDenom.

  • subspace_id - Id of the subspace which creates the denom.
  • sender - Address of user having the permission to manage subspace denoms.
  • subdenom - Subdenom name of the creating denom.
pub fn mint(subspace_id: u64, sender: Addr, amount: Coin) -> MsgMint

Creates a new instance of MsgMint.

  • subspace_id - Id of the subspace which manages the denom.
  • sender - Address of user having the permission to manage subspace denoms.
  • amount - Amount of the minting subspace tokens.
pub fn burn(subspace_id: u64, sender: Addr, amount: Coin) -> MsgBurn

Creates a new instance of MsgBurn.

  • subspace_id - Id of the subspace which manages the denom.
  • sender - Address of user having the permission to manage subspace denoms.
  • amount - Amount of the burning subspace tokens.
pub fn set_denom_metadata( subspace_id: u64, sender: Addr, metadata: Metadata, ) -> MsgSetDenomMetadata

Creates a new instance of MsgSetDenomMetadata.

  • subspace_id - Id of the subspace which manages the denom.
  • sender - Address of user having the permission to manage subspace denoms.
  • metadata - Metadata of the denom.